@@ -2,136 +2,6 @@
 
 (set! *warn-on-reflection* true)
 
-(def java-util-syms
-  '#{Collection,
-     Comparator,
-     Deque,
-     Enumeration,
-     EventListener,
-     Formattable,
-     Iterator,
-     List,
-     ListIterator,
-     Map,
-     Map.Entry,
-     NavigableMap,
-     NavigableSet,
-     Observer,
-     PrimitiveIterator,
-     PrimitiveIterator.OfDouble,
-     PrimitiveIterator.OfInt,
-     PrimitiveIterator.OfLong,
-     Queue,
-     RandomAccess,
-     Set,
-     SortedMap,
-     SortedSet,
-     Spliterator,
-     Spliterator.OfDouble,
-     Spliterator.OfInt,
-     Spliterator.OfLong,
-     Spliterator.OfPrimitive,
-     AbstractCollection,
-     AbstractList,
-     AbstractMap,
-     AbstractMap.SimpleEntry,
-     AbstractMap.SimpleImmutableEntry,
-     AbstractQueue,
-     AbstractSequentialList,
-     AbstractSet,
-     ArrayDeque,
-     ArrayList,
-     Arrays,
-     Base64,
-     Base64.Decoder,
-     Base64.Encoder,
-     BitSet,
-     Calendar,
-     Calendar.Builder,
-     Collections,
-     Currency,
-     Date,
-     Dictionary,
-     DoubleSummaryStatistics,
-     EnumMap,
-     EnumSet,
-     EventListenerProxy,
-     EventObject,
-     FormattableFlags,
-     Formatter,
-     GregorianCalendar,
-     HashMap,
-     HashSet,
-     Hashtable,
-     IdentityHashMap,
-     IntSummaryStatistics,
-     LinkedHashMap,
-     LinkedHashSet,
-     LinkedList,
-     ListResourceBundle,
-     Locale,
-     Locale.Builder,
-     Locale.LanguageRange,
-     LongSummaryStatistics,
-     Objects,
-     Observable,
-     Optional,
-     OptionalDouble,
-     OptionalInt,
-     OptionalLong,
-     PriorityQueue,
-     Properties,
-     PropertyPermission,
-     PropertyResourceBundle,
-     Random,
-     ResourceBundle,
-     ResourceBundle.Control,
-     Scanner,
-     ServiceLoader,
-     SimpleTimeZone,
-     Spliterators,
-     Spliterators.AbstractDoubleSpliterator,
-     Spliterators.AbstractIntSpliterator,
-     Spliterators.AbstractLongSpliterator,
-     Spliterators.AbstractSpliterator,
-     SplittableRandom,
-     Stack,
-     StringJoiner,
-     StringTokenizer,
-     Timer,
-     TimerTask,
-     TimeZone,
-     TreeMap,
-     TreeSet,
-     UUID,
-     Vector,
-     WeakHashMap,
-     Formatter.BigDecimalLayoutForm,
-     Locale.Category,
-     Locale.FilteringMode,
-     ConcurrentModificationException,
-     DuplicateFormatFlagsException,
-     EmptyStackException,
-     FormatFlagsConversionMismatchException,
-     FormatterClosedException,
-     IllegalFormatCodePointException,
-     IllegalFormatConversionException,
-     IllegalFormatException,
-     IllegalFormatFlagsException,
-     IllegalFormatPrecisionException,
-     IllegalFormatWidthException,
-     IllformedLocaleException,
-     InputMismatchException,
-     InvalidPropertiesFormatException,
-     MissingFormatArgumentException,
-     MissingFormatWidthException,
-     MissingResourceException,
-     NoSuchElementException,
-     TooManyListenersException,
-     UnknownFormatConversionException,
-     UnknownFormatFlagsException,
-     ServiceConfigurationError})
-
 (def clj-syms
   '#{{:name * :kind :function}
      {:name *' :kind :function}
@@ -1237,11 +1107,6 @@
      {:name uuid :kind :function}
      {:name write-all :kind :function}})
 
-(def java-util-imports
-  (->> java-util-syms
-       (mapv (juxt identity #(symbol (str "java.util." (name %)))))
-       (into {})))
-
 (def common-refers->info
   {'deftest      'clojure.test
    'testing      'clojure.test
